| Maintainer | hapytexeu+gh@gmail.com |
|---|---|
| Stability | experimental |
| Portability | POSIX |
| Safe Haskell | Safe |
| Language | Haskell2010 |
Data.Char.Duodecimal
Description
The 2150 unicode block contains two characters for duodecimal numbers: numbers with base 12.
In order to represent digits for 10 and 11, unicode has two codepoints: TURNED DIGIT TWO, and TURNED DIGIT THREE. This module makes it
more convenient to convert an Integral number to these digits, as well as converting a number to its duodecimal representation.
Synopsis
- duodecimalDigit :: Integral i => i -> Maybe Char
- duodecimalDigit' :: Integral i => i -> Char
- duodecimalNumber :: Integral i => i -> Text
Convert values to digits
Arguments
| :: Integral i | |
| => i | The given number to convert. |
| -> Char | A unicode character that represents this digit. |
Convert the given Integral number to its unicode character. In case the
value is less than 0, or greater than 11, the behavior is unspecified.